Trait ricat::LineTextFeature
source · pub trait LineTextFeature {
// Required method
fn apply_feature(&mut self, line: &str) -> Option<String>;
}Expand description
Trait defining a text feature that can be applied to lines of input.
Required Methods
sourcefn apply_feature(&mut self, line: &str) -> Option<String>
fn apply_feature(&mut self, line: &str) -> Option<String>
Applies a specific feature to a line of text and returns the modified line or None to omit the line.